@@ -435,7 +435,11 @@ void KWalletManager::shuttingDown()
 
 void KWalletManager::setupWallet()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("kwalletconfig5")});
+#else
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell6"), {QStringLiteral("kcm_kwallet5")});
+#endif
     job->start();
 }
 
@@ -626,3 +630,5 @@ void KWalletManager::activateForStartLikeCall(bool showWindow)
         }
     }
 }
+
+#include "moc_kwalletmanager.cpp"
